@@ -1429,7 +1429,7 @@ class Model(_Base):
 
         return base
 
-    def to_hbjson(self, name="unnamed", folder=None, indent=0,
+    def to_hbjson(self, name="unnamed", folder=None, indent=None,
                   included_prop=None, triangulate_sub_faces=False):
         """Write Honeybee model to HBJSON.
 
@@ -1439,7 +1439,7 @@ class Model(_Base):
                 If unspecified, the default simulation folder will be used. This
                 is usually at "C:\\Users\\USERNAME\\simulation."
             indent: A positive integer to set the indentation used in the resulting
-                HBJSON file. If 0, the JSON will be a single line. (Default: 0).
+                HBJSON file. (Default: None).
             included_prop: List of properties to filter keys that must be included in
                 output dictionary. For example ['energy'] will include 'energy' key if
                 available in properties to_dict. By default all the keys will be
